@@ -14,7 +14,25 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.discovery.footprints.outputs import Outputs
+from collections import Counter
+from typing import List, Dict, Any
+
+
+from enum import Enum
+
+
+class Outputs(Enum):
+    DFG = "dfg"
+    SEQUENCE = "sequence"
+    PARALLEL = "parallel"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    ACTIVITIES = "activities"
+    SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
+    TRACE = "trace"
+
 
 DFG = "dfg"
 FOOTPRINTS_KEY = "footprints"
@@ -22,6 +40,7 @@ START_ACTIVITIES = "start_activities"
 END_ACTIVITIES = "end_activities"
 SEQUENCE = "sequence"
 PARALLEL = "parallel"
+IS_FOOTPRINTS_FIT = "is_footprints_fit"
 
 
 def fp_fitness(fp_log, fp_model, conf_results, parameters=None):
@@ -48,14 +67,12 @@ def fp_fitness(fp_log, fp_model, conf_results, parameters=None):
     if parameters is None:
         parameters = {}
 
-    if type(conf_results) is list:
-        raise Exception("method is working only on entire log footprints")
-    elif type(conf_results) is dict:
-        # extensive conformance variant
-        footprints = conf_results[FOOTPRINTS_KEY]
-    else:
-        # normal conformance variant
-        footprints = conf_results
+    fit_traces = None
+    if isinstance(conf_results, list):
+        fit_traces = len([x for x in conf_results if x[IS_FOOTPRINTS_FIT]])/len(conf_results) * 100.0
+
+    fp_log = flatten_fp(fp_log)
+    conf_results = flatten_conf(conf_results)
 
     dfg = fp_log[DFG]
     num_sequence_log = len(fp_log[SEQUENCE])
@@ -64,17 +81,23 @@ def fp_fitness(fp_log, fp_model, conf_results, parameters=None):
     num_end_activities_log = len(fp_log[END_ACTIVITIES])
     num_start_activities_dev = len(conf_results[START_ACTIVITIES])
     num_end_activities_dev = len(conf_results[END_ACTIVITIES])
+    footprints = conf_results[FOOTPRINTS_KEY]
 
     if dfg:
         sum_dfg = float(sum(x for x in dfg.values()))
         sum_dev = float(sum(dfg[x] for x in footprints))
 
-        return ((1.0 - sum_dev / sum_dfg) * (num_sequence_log + num_parallel_log) + (
+        fitness = ((1.0 - sum_dev / sum_dfg) * (num_sequence_log + num_parallel_log) + (
                     num_start_activities_log + num_end_activities_log - num_start_activities_dev - num_end_activities_dev)) / (
                            num_sequence_log + num_parallel_log + num_start_activities_log + num_end_activities_log)
+    else:
+        # return fitness 1.0 if DFG is empty
+        fitness = 1.0
 
-    # return fitness 1.0 if DFG is empty
-    return 1.0
+    if fit_traces is not None:
+        return {"perc_fit_traces": fit_traces, "log_fitness": fitness}
+
+    return fitness
 
 
 def fp_precision(fp_log, fp_model, parameters=None):
@@ -99,6 +122,9 @@ def fp_precision(fp_log, fp_model, parameters=None):
     if parameters is None:
         parameters = {}
 
+    fp_log = flatten_fp(fp_log)
+    fp_model = flatten_fp(fp_model)
+
     log_configurations = fp_log[Outputs.SEQUENCE.value].union(fp_log[Outputs.PARALLEL.value])
     model_configurations = fp_model[Outputs.SEQUENCE.value].union(fp_model[Outputs.PARALLEL.value])
 
@@ -107,3 +133,55 @@ def fp_precision(fp_log, fp_model, parameters=None):
 
     # return precision 1.0 if model configurations are empty
     return 1.0
+
+
+def flatten_fp(fp: List[Dict[str, Any]]) -> Dict[str, Any]:
+    """
+    Flattens the trace-based footprints to the footprints of the overall log
+
+    Parameters
+    ---------------
+    fp
+        Trace-based footprints
+
+    Returns
+    --------------
+    log_fp
+        Overall log footprints
+    """
+    if isinstance(fp, list):
+        res = {DFG: Counter(), SEQUENCE: set(), PARALLEL: set(), START_ACTIVITIES: set(), END_ACTIVITIES: set()}
+        for el in fp:
+            for x, y in el[DFG].items():
+                res[DFG][x] += y
+            res[SEQUENCE] = res[SEQUENCE].union(el[SEQUENCE])
+            res[PARALLEL] = res[PARALLEL].union(el[PARALLEL])
+            res[START_ACTIVITIES] = res[START_ACTIVITIES].union(el[START_ACTIVITIES])
+            res[END_ACTIVITIES] = res[END_ACTIVITIES].union(el[END_ACTIVITIES])
+        return res
+    return fp
+
+
+def flatten_conf(conf: List[Dict[str, Any]]) -> Dict[str, Any]:
+    """
+    Flattens the trace-based conformance checking results (obtained using footprints) to the conformance checking
+    results on the overall log
+
+    Parameters
+    ----------------
+    conf
+        Trace-based conformance checking results
+
+    Returns
+    ----------------
+    log_conf
+        Overall log conformance checking results
+    """
+    if isinstance(conf, list):
+        res = {FOOTPRINTS_KEY: set(), START_ACTIVITIES: set(), END_ACTIVITIES: set()}
+        for el in conf:
+            res[FOOTPRINTS_KEY] = res[FOOTPRINTS_KEY].union(el[FOOTPRINTS_KEY])
+            res[START_ACTIVITIES] = res[START_ACTIVITIES].union(el[START_ACTIVITIES])
+            res[END_ACTIVITIES] = res[END_ACTIVITIES].union(el[END_ACTIVITIES])
+        return res
+    return conf
