@@ -24,6 +24,10 @@ from pm4py.util import exec_utils
 from enum import Enum
 from pm4py.util import constants
 
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.log.obj import EventLog
+from pm4py.objects.org.sna.obj import SNA
+
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
@@ -31,7 +35,7 @@ class Parameters(Enum):
     METRIC_NORMALIZATION = "metric_normalization"
 
 
-def apply(log, parameters=None):
+def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> SNA:
     """
     Calculates the Joint Activities / Similar Task metric
 
@@ -66,12 +70,13 @@ def apply(log, parameters=None):
         i = resources_keys.index(arc[0])
         j = activities_keys.index(arc[1])
         rsc_act_matrix[i, j] += activity_resource_couples[arc]
-    metric_matrix = np.zeros((len(resources_keys), len(resources_keys)))
+    connections = {}
     for i in range(rsc_act_matrix.shape[0]):
         vect_i = rsc_act_matrix[i, :]
         for j in range(rsc_act_matrix.shape[0]):
             if not i == j:
                 vect_j = rsc_act_matrix[j, :]
                 r, p = pearsonr(vect_i, vect_j)
-                metric_matrix[i, j] = r
-    return [metric_matrix, resources_keys, False]
+                connections[(resources_keys[i], resources_keys[j])] = r
+
+    return SNA(connections, False)
