@@ -16,3 +16,7 @@
 '''
 
 from pm4py.algo.simulation.montecarlo import algorithm, variants, utils
+
+import warnings
+
+warnings.warn("The simulation.montecarlo package will be removed in a future release.")
