@@ -21,6 +21,7 @@ PARAM_OBJECT_ID = "param:object:id"
 PARAM_OBJECT_TYPE = "param:object:type"
 PARAM_OBJECT_TYPE_PREFIX_EXTENDED = "param:object:type:prefix:extended"
 PARAM_QUALIFIER = "param:qualifier"
+PARAM_CHNGD_FIELD = "param:chngfield"
 
 DEFAULT_EVENT_ID = "ocel:eid"
 DEFAULT_EVENT_ACTIVITY = "ocel:activity"
@@ -29,6 +30,7 @@ DEFAULT_OBJECT_ID = "ocel:oid"
 DEFAULT_OBJECT_TYPE = "ocel:type"
 DEFAULT_OBJECT_TYPE_PREFIX_EXTENDED = "ocel:type:"
 DEFAULT_QUALIFIER = "ocel:qualifier"
+DEFAULT_CHNGD_FIELD = "ocel:field"
 
 OCEL_PREFIX = "ocel:"
 OCEL_EVENTS_KEY = "ocel:events"
