@@ -120,6 +120,6 @@ def apply(ocpn: Dict[str, Any], parameters: Optional[Dict[Any, Any]] = None) ->
                 viz.edge(transition_map[arc.source], places[arc.target], color=otc, penwidth=penwidth)
 
     viz.attr(rankdir=rankdir)
-    viz.format = image_format
+    viz.format = image_format.replace("html", "plain-ext")
 
     return viz
